/* olympus-wrap.h
 *
 * Copyright (c) 2012 Marcus Meissner  <marcus@jet.franken.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */

#ifndef CAMLIBS_PTP2_OLYMPUS_WRAP_H
#define CAMLIBS_PTP2_OLYMPUS_WRAP_H

#include <gphoto2/gphoto2-port.h>

uint16_t olympus_setup (PTPParams *params);

#endif /* !defined(CAMLIBS_PTP2_OLYMPUS_WRAP_H) */
